@@ -53,7 +53,6 @@ class Course(models.Model):
 
 
 class Section(models.Model):
-    pre_name = models.CharField(max_length=180, verbose_name='前缀标题', null=True, blank=True)
     name = models.CharField(max_length=180, verbose_name='课件名字')  # 名字
     info = models.TextField(null=True, blank=True, verbose_name='正文')
     videos = models.ManyToManyField("bee_django_course.Video")
@@ -93,6 +92,9 @@ class Section(models.Model):
         else:
             return '否'
 
+    def get_questions(self):
+        return self.sectionquestion_set.all()
+
     # 添加问题
     def add_question(self, question_type):
         question = SectionQuestion()
@@ -117,6 +119,7 @@ class UserSectionNote(models.Model):
 
 # 课件的附件
 class SectionAttach(models.Model):
+    name = models.CharField(max_length=180, verbose_name='附件名称', null=True, blank=True)
     section = models.ForeignKey(Section)
     file = models.FileField(verbose_name='附件', upload_to='sections/%Y/%m/%d/')
     upload_at = models.DateTimeField(auto_now_add=True)
@@ -125,16 +128,20 @@ class SectionAttach(models.Model):
         db_table = 'bee_django_course_section_attach'
 
     def file_name(self):
-        return os.path.basename(self.file.name)
+        if self.name:
+            return self.name
+        else:
+            return os.path.basename(self.file.name)
 
 
 # 课程课件中间件
 class CourseSectionMid(models.Model):
     course = models.ForeignKey("bee_django_course.Course", verbose_name='课程')  # 课程
     section = models.ForeignKey("bee_django_course.Section", verbose_name="课件")  # 课程包
-    pionts = models.IntegerField(default=0, verbose_name='通过后获得的M币')
+    points = models.IntegerField(default=0, verbose_name='通过后获得的M币')
     order_by = models.IntegerField(default=0, verbose_name="顺序")  # 顺序
     mins = models.IntegerField(null=True, blank=True, verbose_name='达标分钟数')  # 达标分钟数
+    pre_name = models.CharField(max_length=180, verbose_name='前缀标题', null=True, blank=True)
 
     class Meta:
         db_table = 'bee_django_course_section_mid'
@@ -194,8 +201,8 @@ class SectionQuestion(models.Model):
     question_type = models.IntegerField(default=1, verbose_name='问题类型', choices=COURSE_SECTION_QUESTION_TYPE_CHOICES)
     order_by = models.IntegerField(default=0, verbose_name='顺序')
     options = models.ManyToManyField("bee_django_course.SectionQuestionOption")
-    tip_wrong = models.TextField(null=True,verbose_name="错误时提示词")
-    tip_correct = models.TextField(null=True,verbose_name="正确时提示词")
+    tip_wrong = models.TextField(null=True, verbose_name="错误时提示词")
+    tip_correct = models.TextField(null=True, verbose_name="正确时提示词")
 
     class Meta:
         db_table = 'bee_django_course_section_question'
@@ -203,8 +210,8 @@ class SectionQuestion(models.Model):
 
     # 添加选项
     def add_options(self, count=1):
-        # 单选
-        if int(self.question_type) == 1:
+        # 单选 或多选
+        if int(self.question_type) == 1 or int(self.question_type) == 2:
             new_options = []
             for i in range(1, count + 1):
                 option = SectionQuestionOption()
@@ -216,6 +223,11 @@ class SectionQuestion(models.Model):
                 new_options.append(option)
             return new_options
 
+    # 获取答题的正确答案
+    def get_correct_options(self):
+        return SectionQuestionOption.objects.filter(question=self, is_correct=True)
+
+
 
 class SectionQuestionOption(models.Model):
     question = models.ForeignKey(SectionQuestion, verbose_name='问题')
@@ -237,6 +249,29 @@ def create_user(sender, **kwargs):
         section_question.add_options(3)
 
 
+class UserQuestionAnswerRecord(models.Model):
+    user = models.ForeignKey(settings.AUTH_USER_MODEL)  # 学生
+    question = models.ForeignKey(SectionQuestion)  # 问题
+    answer = models.ForeignKey(SectionQuestionOption)  # 答案
+    created_at = models.DateTimeField(auto_now_add=True)
+
+    class Meta:
+        db_table = 'bee_django_course_user_question_answer_record'
+        app_label = 'bee_django_course'
+        ordering = ['-created_at']
+
+    def __unicode__(self):
+        return ("UserQuestionAnswerRecord->user:" + self.user.username + ",question:" + self.question.question)
+
+    @classmethod
+    def get_user_question_answer_options(cls, question, user):
+        return cls.objects.filter(question=question, user=user)
+        # answer_option_list = []
+        # for record in records:
+        #     option_id_list.append(record.answer)
+        # return SectionQuestionOption.objects.filter(id__in=option_id_list)
+
+
 class UserLive(models.Model):
     provider_name = models.CharField(max_length=180)  # 平台商
     cc_user_id = models.CharField(max_length=180, null=True)  # CC账号
@@ -313,6 +348,11 @@ class UserCourse(models.Model):
     class Meta:
         db_table = 'bee_django_course_user_course'
 
+    def get_pass(self):
+        self.status = 1
+        self.passed_at = timezone.now()
+        self.save()
+
 
 class UserCourseSection(models.Model):
     user_course = models.ForeignKey(UserCourse)
@@ -346,12 +386,13 @@ class UserCourseSection(models.Model):
 
     def auto_pass_check(self):
         if not self.section.auto_pass:
-            return
+            return False
 
         section = self.section
         textwork_check = False
         imagework_check = False
         videowork_check = False
+        question_check = False
 
         if section.has_textwork:
             if self.userassignment_set.exists():
@@ -372,22 +413,28 @@ class UserCourseSection(models.Model):
         else:
             videowork_check = True
 
+        if section.has_questionwork:
+            if self.question_passed:
+                question_check = True
+        else:
+            question_check = True
+
         # 所有检查条件都通过，才可自动通过
-        if textwork_check & imagework_check & videowork_check:
-            self.status = 2
-            self.updated_at = timezone.now()
-            self.save()
-            next_section = self.next_section()
-            if next_section:
-                next_section.open_ucs()
+        if textwork_check & imagework_check & videowork_check & question_check:
+            return True
+        else:
+            return False
 
     def open_ucs(self):
         # 如果课件为自动通过 先检查是否满足通过条件
-        self.auto_pass_check()
+        rc = self.auto_pass_check()
 
-        self.status = 1
-        self.updated_at = timezone.now()
-        self.save()
+        if rc:
+            self.get_pass()
+        else:
+            self.status = 1
+            self.updated_at = timezone.now()
+            self.save()
 
     def is_learning(self):
         return self.status == 1
@@ -414,6 +461,9 @@ class UserCourseSection(models.Model):
 
     @transaction.atomic
     def get_pass(self, score=0, comment=None):
+        if self.status == 2:  # 避免重复操作
+            return
+
         self.score = score
         self.comment = comment
         self.updated_at = timezone.now()
@@ -430,6 +480,8 @@ class UserCourseSection(models.Model):
             next_section = self.next_section()
             if next_section:
                 next_section.open_ucs()
+            else:
+                self.user_course.get_pass()  # 所有课程都通过了，则此课学习完成，通过
 
     @transaction.atomic
     def reject(self):
@@ -446,9 +498,11 @@ class UserCourseSection(models.Model):
         self.save()
 
         # 检查是否可以自动通过
-        self.auto_pass_check()
+        rc = self.auto_pass_check()
+        if rc:
+            self.get_pass()
 
-    def next_section(self):
+    def next_section(self, is_open=False):
         order_sets = CourseSectionMid.objects.filter(course=self.user_course.course,
                                                      section=self.section)
         if order_sets.exists():
@@ -456,7 +510,12 @@ class UserCourseSection(models.Model):
             mids = CourseSectionMid.objects.filter(course=self.user_course.course, order_by__gt=order)
             if mids.exists():
                 mid = mids.first()
-                ucs = UserCourseSection.objects.filter(user_course=self.user_course, section=mid.section)
+                if is_open:
+                    ucs = UserCourseSection.objects.filter(user_course=self.user_course,
+                                                           status__in=[1, 2, 3, 4],
+                                                           section=mid.section)
+                else:
+                    ucs = UserCourseSection.objects.filter(user_course=self.user_course, section=mid.section)
                 if ucs.exists():
                     return ucs.first()
                 else:
@@ -466,6 +525,20 @@ class UserCourseSection(models.Model):
         else:
             return None
 
+    def get_section_mid_prename(self):
+        try:
+            mid = CourseSectionMid.objects.get(course=self.user_course.course, section=self.section)
+            return mid.pre_name
+        except:
+            return None
+
+    def get_section_mid_points(self):
+        try:
+            mid = CourseSectionMid.objects.get(course=self.user_course.course, section=self.section)
+            return mid.points
+        except:
+            return 0
+
 
 class UserAssignment(models.Model):
     user_course_section = models.ForeignKey(UserCourseSection)
