@@ -16,7 +16,7 @@ from django.contrib import messages
 from django.contrib.auth import get_user_model
 from django.conf import settings
 from .models import Course, Section, CourseSectionMid, Video, UserLive, UserCourse, UserCourseSection, \
-    Preference, UserSectionNote, SectionVideo, SectionQuestion, SectionQuestionOption
+    Preference, UserSectionNote, SectionVideo, SectionQuestion, SectionQuestionOption, UserQuestionAnswerRecord
 from .forms import CourseForm, SectionForm, CourseSectionForm, CourseSectionOrderForm, VideoForm, UploadImageForm, \
     UserCourseForm, UserAssignmentForm, UserAssignmentImageForm, SectionVideoForm, PreferenceForm, \
     section_attach_form, UserSectionNoteForm, SectionVideoOrderForm, LivePlayLogsForm, UserLiveCommentForm
@@ -45,13 +45,14 @@ class CourseRedirectView(RedirectView):
     #     pattern_name = 'bee_django_course:section_list'
     # else:
     #     pattern_name = 'bee_django_course:section_list'
-
+    query_string = True
     def get_redirect_url(self, *args, **kwargs):
         if self.request.user.has_perm('bee_django_course.view_all_courses'):
             # 跳转 CourseList
             self.pattern_name = 'bee_django_course:course_list'
         elif self.request.user.has_perm('bee_django_course.view_teach_usercoursessection'):
-            self.pattern_name = 'bee_django_course:live_list'
+            # self.pattern_name = 'bee_django_course:live_list'
+            self.url = reverse('bee_django_course:live_list',kwargs={"user_id":0})
         else:
             self.url = '/'
         return super(CourseRedirectView, self).get_redirect_url(*args, **kwargs)
@@ -70,7 +71,7 @@ class CourseList(ListView):
         if request.user.has_perm('bee_django_course.view_all_courses'):
             return super(CourseList, self).get(request, *args, **kwargs)
         elif request.user.has_perm('bee_django_course.view_teach_usercoursessection'):
-            return redirect(reverse('bee_django_course:live_list'))
+            return redirect(reverse('bee_django_course:live_list',kwargs={"user_id":0}))
 
 
 @method_decorator(cls_decorator(cls_name='CourseDetail'), name='dispatch')
@@ -118,6 +119,13 @@ class SectionList(ListView):
     paginate_by = 20
     queryset = Section.objects.all()
 
+    def get_queryset(self):
+        section_name = self.request.GET.get('section_name')
+        if section_name:
+            return self.queryset.filter(name__contains=section_name)
+        else:
+            return self.queryset
+
 
 @method_decorator(cls_decorator(cls_name='SectionDetail'), name='dispatch')
 class SectionDetail(DetailView):
@@ -288,7 +296,6 @@ def delete_courseectionmid(request, csm_id):
         })
 
 
-
 @method_decorator(cls_decorator(cls_name='VideoList'), name='dispatch')
 class VideoList(ListView):
     template_name = 'bee_django_course/video/video_list.html'
@@ -414,6 +421,15 @@ class LiveList(ListView):
     paginate_by = 20
     queryset = None
 
+
+    def get_user(self):
+        user_id = self.kwargs["user_id"]
+        if not user_id in [None,'0']:
+            user = User.objects.get(id=user_id)
+            return user
+        return None
+
+
     def get_queryset(self):
         if self.request.user.has_perm("bee_django_course.view_all_userlives"):
             self.queryset = UserLive.objects.filter(status=1)
@@ -422,34 +438,40 @@ class LiveList(ListView):
             self.queryset = UserLive.objects.filter(user__in=users, status=1).order_by('-created_at')
         else:
             return []
+        user = self.get_user()
+        if user:
+            self.queryset = self.queryset.filter(user = user)
         return self.queryset
 
     def get_context_data(self, **kwargs):
         context = super(LiveList, self).get_context_data(**kwargs)
         # context["vdieo_provider_name"] = settings.COURSE_VIDEO_PROVIDER_NAME
         context["live_url"] = None
+        context["user"] = self.get_user()
         return context
 
 
-# 查看单个学生的所有录播
-@method_decorator(cls_decorator(cls_name='UserLiveList'), name='dispatch')
-class UserLiveList(ListView):
-    template_name = 'bee_django_course/live/user_live_list.html'
-    context_object_name = 'user_live_list'
-    paginate_by = 20
-    queryset = UserLive.objects.filter(status__in=[1,2]).order_by('-created_at')
 
-    def get_queryset(self):
-        return UserLive.objects.filter(user_id=self.kwargs["user_id"], status__in=[1,2]).order_by('-created_at')
 
-    def get_context_data(self, **kwargs):
-        context = super(UserLiveList, self).get_context_data(**kwargs)
-        # TODO
-        user = get_object_or_404(User, pk=self.kwargs["user_id"])
-        # context["vdieo_provider_name"] = settings.COURSE_VIDEO_PROVIDER_NAME
-        context["live_url"] = None
-        context["user"] = user
-        return context
+# # 查看单个学生的所有录播
+# @method_decorator(cls_decorator(cls_name='UserLiveList'), name='dispatch')
+# class UserLiveList(ListView):
+#     template_name = 'bee_django_course/live/user_live_list.html'
+#     context_object_name = 'user_live_list'
+#     paginate_by = 20
+#     queryset = UserLive.objects.filter(status__in=[1, 2]).order_by('-created_at')
+#
+#     def get_queryset(self):
+#         return UserLive.objects.filter(user_id=self.kwargs["user_id"], status__in=[1, 2]).order_by('-created_at')
+#
+#     def get_context_data(self, **kwargs):
+#         context = super(UserLiveList, self).get_context_data(**kwargs)
+#         # TODO
+#         user = get_object_or_404(User, pk=self.kwargs["user_id"])
+#         # context["vdieo_provider_name"] = settings.COURSE_VIDEO_PROVIDER_NAME
+#         context["live_url"] = None
+#         context["user"] = user
+#         return context
 
 
 # @func_decorator('play_video')
@@ -788,7 +810,11 @@ def user_assignment_image_upload(request, ucs_id):
             # 上传图片后，也要更新UCS的更新时间
             ucs.updated_at = timezone.now()
             ucs.save()
-            ucs.auto_pass_check()
+
+            rc = ucs.auto_pass_check()
+            if rc:
+                ucs.get_pass()
+
             messages.success(request, '上传成功')
             return redirect(reverse('bee_django_course:user_assignment', kwargs={'ucs_id': ucs.id}))
         else:
@@ -867,16 +893,16 @@ def manage_user_course(request, user_id):
 
 # 管理查看用户待评分文字作业
 def manage_user_assignments(request):
-    if request.user.has_perm("bee_django_user.view_all_usercoursesection"):
+    if request.user.has_perm("bee_django_course.view_all_usercoursesection"):
         data_list = UserCourseSection.objects.filter(status__in=[1, 4]) \
             .filter(Q(userassignment__isnull=False) | Q(userassignmentimage__isnull=False)) \
-            .order_by('-updated_at')
-    elif request.user.has_perm("bee_django_user.view_teach_usercoursesection"):
+            .order_by('-updated_at').distinct()
+    elif request.user.has_perm("bee_django_course.view_teach_usercoursessection"):
         users = get_teach_users(request.user)
         data_list = UserCourseSection.objects.filter(status__in=[1, 4]) \
             .filter(user_course__user__in=users) \
             .filter(Q(userassignment__isnull=False) | Q(userassignmentimage__isnull=False)) \
-            .order_by('-updated_at')
+            .order_by('-updated_at').distinct()
     else:
         data_list = []
 
@@ -1351,7 +1377,6 @@ class SectionQuestionOptionDelete(TemplateView):
         })
 
 
-
 # 学生回答问题页
 class SectionQuestionAnswer(TemplateView):
     template_name = 'bee_django_course/question/answer.html'
@@ -1366,8 +1391,6 @@ class SectionQuestionAnswer(TemplateView):
         ucs = UserCourseSection.objects.get(id=user_section_id)
         return ucs
 
-
-
     def get_context_data(self, **kwargs):
         context = super(SectionQuestionAnswer, self).get_context_data(**kwargs)
         ucs = self.get_ucs()
@@ -1375,32 +1398,99 @@ class SectionQuestionAnswer(TemplateView):
         context["ex_url"] = settings.COURSE_EX_URL
         return context
 
-    # def post(self, request, *args, **kwargs):
-    #     ucs = self._get_user_section()
-    #     print(ucs.section)
-    #     return JsonResponse(data={
-    #         'error': 0
-    #     })
+        # def post(self, request, *args, **kwargs):
+        #     ucs = self._get_user_section()
+        #     print(ucs.section)
+        #     return JsonResponse(data={
+        #         'error': 0
+        #     })
+
+
+# 根据每个学生查看问卷调查
+class UserQuestionAnswerRecordList(ListView):
+    template_name = 'bee_django_course/question/user_question_answer_record_list.html'
+    context_object_name = 'question_list'
+    paginate_by = 20
+    queryset = None
+
+    def get_ucs(self):
+        user_section_id = self.kwargs["user_section_id"]
+        print(user_section_id)
+        if not user_section_id in ["0", None]:
+            ucs = UserCourseSection.objects.get(id=user_section_id)
+            return ucs
+        else:
+            return None
+
+    def get_user(self):
+        ucs = self.get_ucs()
+        if ucs:
+            return ucs.user_course.user
+        return None
+
+    def get_queryset(self):
+        ucs = self.get_ucs()
+        if ucs:
+            question_list = ucs.section.get_questions()
+            return question_list
+        else:
+            return SectionQuestion.objects.all()
+
+    def get_context_data(self, **kwargs):
+        context = super(UserQuestionAnswerRecordList, self).get_context_data(**kwargs)
+        ucs = self.get_ucs()
+        if ucs:
+            user = ucs.user_course.user
+        else:
+            user = None
+        context["ucs"] = ucs
+        context["user"] = user
+        return context
+
 
 # 用户答题正确，更新ucs状态，返回用户学习课程的列表
 def ucs_question_passed(request, ucs_id):
     if request.method == "POST":
         ucs = get_object_or_404(UserCourseSection, pk=ucs_id)
+        questions = request.POST.get("questions")
+        questions = json.loads(questions)
+        # 检查是否保存，如没有存过，则保存用户答案
+        user = request.user
+        for question in questions:
+            answers = question["answers"]
+            question_id = question["id"]
+            records = UserQuestionAnswerRecord.objects.filter(user=user, question_id=question_id)
+            if records.exists():
+                continue
+            for answer in answers:
+                record = UserQuestionAnswerRecord()
+                record.user = user
+                record.answer_id = answer
+                record.question_id = question_id
+                record.save()
 
         ucs.question_passed = True
         ucs.question_passed_at = timezone.now()
         ucs.save()
 
-        return JsonResponse(data={
-            'return_link': reverse('bee_django_course:user_course_detail', kwargs={
+        rc = ucs.auto_pass_check()
+        if rc:
+            ucs.get_pass()
+
+        if settings.COURSE_QUESTION_RETURN_LINK:
+            return_link = settings.COURSE_QUESTION_RETURN_LINK
+        else:
+            return_link = reverse('bee_django_course:user_course_detail', kwargs={
                 'user_course_id': ucs.user_course_id,
             })
+
+        return JsonResponse(data={
+            'return_link': return_link,
         })
 
 
 # 删除(隐藏）录播(UserLive)
 def delete_user_live(request, user_live_id):
-
     if request.method == "POST":
         user_live = get_object_or_404(UserLive, pk=user_live_id)
 
@@ -1414,5 +1504,3 @@ def delete_user_live(request, user_live_id):
         return JsonResponse(data={
             'rc': 0,
         })
-
-
